# -*- coding: utf-8 -*-

"""
:module: d2lvalence
:synopsis: Package for D2L Valence client applications.
:license: Apache v2.0, see LICENSE for more details.

:see: http://www.desire2learn.com/valencehome for more information about the Valence project.
"""

__title__ = 'd2lvalence'
__version__ = '0.1.11'
__build__ = 0x00010B
__author__ = 'Desire2Learn Extensibility'
__license__ = 'Apache v2'
__copyright__ = 'Copyright 2012 Desire2Learn Inc.'
